import pytest

def pytest_addoption(parser):
    parser.addoption('--server', action='store', default='localhost')
    parser.addoption('--share', action='store', default='share')
    parser.addoption('--username', action='store', default='user1')
    parser.addoption('--password', action='store', default='password1')

@pytest.fixture(autouse=True, scope='session')
def config(pytestconfig):
    server = pytestconfig.getoption('server')
    share = pytestconfig.getoption('share')
    username = pytestconfig.getoption('username')
    password = pytestconfig.getoption('password')
    uri = 'smb://{}/{}/'.format(server, share)
    yield {
        'server': server,
        'share': share,
        'username': username,
        'password': password,
        'uri': uri,
    }



import smbc

def test_auth_succes(config):
    ctx = smbc.Context()
    ctx.optionNoAutoAnonymousLogin = True
    cb = lambda se, sh, w, u, p: (w, config['username'], config['password'])
    ctx.functionAuthData = cb
    d = ctx.opendir(config['uri'])
    assert d != None

def test_auth_failed_noauth(config):
    ctx = smbc.Context()
    ctx.optionNoAutoAnonymousLogin = True
    try:
        ctx.opendir(config['uri'])
    except smbc.PermissionError:
        assert True
    else:
        assert False

def test_auth_failed_nopass(config):
    ctx = smbc.Context()
    ctx.optionNoAutoAnonymousLogin = True
    cb = lambda se, sh, w, u, p: (w, config['username'], "")
    ctx.functionAuthData = cb
    try:
        ctx.opendir(config['uri'])
    except smbc.PermissionError:
        assert True
    else:
        assert False

def test_auth_failed_nouser(config):
    ctx = smbc.Context()
    ctx.optionNoAutoAnonymousLogin = True
    cb = lambda se, sh, w, u, p: (w, "", config['password'])
    ctx.functionAuthData = cb
    try:
        ctx.opendir(config['uri'])
    except smbc.PermissionError:
        assert True
    else:
        assert False



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import smbc

def main():
    ctx = smbc.Context()
    uri = 'smb://localhost'
    entries = ctx.opendir(uri).getdents()
    for d in entries:
        print(d)

if __name__ == '__main__':
    main()
